@@ -1,29 +1,31 @@
 /*
 
-  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filteractionmissingfolderdialog.h"
-#include "filter/kmfilteraccountlist.h"
 #include "folder/folderrequester.h"
 #include "kernel/mailkernel.h"
-#include "tag/addtagdialog.h"
 #include "util/mailutil.h"
 
 #include <Akonadi/EntityMimeTypeFilterModel>
 
-#include <KIdentityManagement/IdentityCombo>
-
 #include <KLocalizedString>
 
 #include <KConfigGroup>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QListWidget>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
+namespace
+{
+static const char myFilterActionMissingCollectionDialogConfigGroupName[] = "FilterActionMissingCollectionDialog";
+}
 
 FilterActionMissingFolderDialog::FilterActionMissingFolderDialog(const Akonadi::Collection::List &list,
                                                                  const QString &filtername,
@@ -94,18 +96,18 @@ FilterActionMissingFolderDialog::~FilterActionMissingFolderDialog()
 
 void FilterActionMissingFolderDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingCollectionDialog");
-
-    const QSize size = group.readEntry("Size", QSize(500, 300));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(500, 300));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingCollectionDialogConfigGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void FilterActionMissingFolderDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingCollectionDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingCollectionDialogConfigGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
 
 void FilterActionMissingFolderDialog::slotFolderChanged(const Akonadi::Collection &col)
