@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONPLAYSOUND_H
-#define MAILCOMMON_FILTERACTIONPLAYSOUND_H
+#pragma once
 
 #include "filteractionwithtest.h"
 
@@ -39,5 +38,3 @@ private:
     mutable Phonon::MediaObject *mPlayer = nullptr;
 };
 }
-
-#endif
